==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/SaveAs/ts/SaveAs_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translation>デフォルトフォーマット:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>２４ビットカラーをサポートしない形式の時警告を出す</translation>
    </message>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>Load/Save</source>
        <translation>ロード/セーブ</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="vanished">形式を指定して保存</translation>
    </message>
    <message>
        <source>No export filters</source>
        <translation type="vanished">エクスポートフィルタがありません</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>エクスポートフィルタがみつかりません。中断します...</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Format:</source>
        <translation>フォーマット:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>&amp;A 形式を指定して保存...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/SaveAs/ts/SaveAs_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation>ファイルダイアログ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation>システムのファイル選択ダイアログを使用</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation>保存中</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translation>デフォルトフォーマット:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>２４ビットカラーをサポートしない形式の時警告を出す</translation>
    </message>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">ロード/セーブ</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="vanished">形式を指定して保存</translation>
    </message>
    <message>
        <source>No export filters</source>
        <translation type="vanished">エクスポートフィルタがありません</translation>
    </message>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open/Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>エクスポートフィルタがみつかりません。中断します...</translation>
    </message>
    <message>
        <location line="+74"/>
        <source>Format:</source>
        <translation>フォーマット:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>&amp;A 形式を指定して保存...</translation>
    </message>
</context>
</TS>
